pulp-certguard
==============

.. figure:: https://github.com/pulp/pulp-certguard/workflows/Pulp%20CI/badge.svg
   :alt: Pulp CI

A Pulp plugin that provides an X.509 capable ``ContentGuard`` for pulpcore. Instances of
``X509CertGuard`` are useful for requiring clients to submit a certificate proving their entitlement
to content before receiving the content.

For more information, please see the `documentation <https://docs.pulpproject.org/pulp_certguard>`_
or the `Pulp project page <https://pulpproject.org>`_.
